@@ -198,7 +198,7 @@ def main():
 
         status = ""
         percentage = 0
-        while status != "finished":
+        while status != "finished" and status != "failed":
             status, scan_percentage = check_scan(scan_id, project_id, apikey, baseurl)
             if scan_percentage and scan_percentage != percentage:
                 percentage = scan_percentage
@@ -210,6 +210,7 @@ def main():
     # scan_sourcecode finish means scan finish, no need to check scan status, thus no need project id.
     # loop = asyncio.get_event_loop()
     if report_format:
+        
         output_folder = os.path.join(
             report_path,
             os.path.splitext(os.path.basename(local_file))[0]
@@ -218,6 +219,9 @@ def main():
         )
         logger.info(f"report output folder: {output_folder}")
 
+        if not os.path.exists(report_path):
+            os.mkdir(report_path)
+
         if not os.path.exists(output_folder):
             os.mkdir(output_folder)
 
@@ -247,6 +251,7 @@ def main():
             # loop.run_until_complete(
             #     get_report(scan_id, apikey, baseurl, report_format, output_folder)
             # )
+            logger.info(f"Generalize report for scan {scan_id}")
             get_report(scan_id, apikey, baseurl, report_format, output_folder)
 
     get_scan_summary(scan_id, apikey, baseurl)
